@@ -1,15 +1,15 @@
-require File.dirname(__FILE__) + '/helper'
+require File.expand_path('../helper', __FILE__)
 
 begin
 require 'sass'
 
 class SassTest < Test::Unit::TestCase
   def sass_app(options = {}, &block)
-    mock_app {
+    mock_app do
       set :views, File.dirname(__FILE__) + '/views'
       set options
-      get '/', &block
-    }
+      get('/', &block)
+    end
     get '/'
   end
 
@@ -35,9 +35,9 @@ class SassTest < Test::Unit::TestCase
   end
 
   it 'defaults allows setting content type globally' do
-    sass_app(:sass => { :content_type => 'html' }) do
+    sass_app(:sass => { :content_type => 'html' }) {
       sass "#sass\n  :background-color white\n"
-    end
+    }
     assert ok?
     assert_equal "text/html;charset=utf-8", response['Content-Type']
   end
@@ -55,50 +55,50 @@ class SassTest < Test::Unit::TestCase
   end
 
   it "raises error if template not found" do
-    mock_app {
-      get('/') { sass :no_such_template }
-    }
+    mock_app { get('/') { sass :no_such_template } }
     assert_raise(Errno::ENOENT) { get('/') }
   end
 
   it "passes SASS options to the Sass engine" do
-    sass_app {
-      sass "#sass\n  :background-color white\n  :color black\n",
+    sass_app do
+      sass(
+        "#sass\n  :background-color white\n  :color black\n",
         :style => :compact
-    }
+      )
+    end
     assert ok?
-    assert_equal "#sass { background-color: white; color: black; }\n", body
+    assert_equal("#sass { background-color: white; color: black; }\n", body)
   end
 
   it "passes default SASS options to the Sass engine" do
-    mock_app {
+    mock_app do
       set :sass, {:style => :compact} # default Sass style is :nested
-      get '/' do
-        sass "#sass\n  :background-color white\n  :color black\n"
-      end
-    }
+      get('/') { sass("#sass\n  :background-color white\n  :color black\n") }
+    end
     get '/'
     assert ok?
     assert_equal "#sass { background-color: white; color: black; }\n", body
   end
 
   it "merges the default SASS options with the overrides" do
-    mock_app {
+    mock_app do
       # default Sass attribute_syntax is :normal (with : in front)
       set :sass, {:style => :compact, :attribute_syntax => :alternate }
-      get '/' do
-        sass "#sass\n  background-color: white\n  color: black\n"
-      end
-      get '/raised' do
+      get('/') { sass("#sass\n  background-color: white\n  color: black\n") }
+      get('/raised') do
         # retains global attribute_syntax settings
-        sass "#sass\n  :background-color white\n  :color black\n",
+        sass(
+          "#sass\n  :background-color white\n  :color black\n",
           :style => :expanded
+        )
       end
-      get '/expanded_normal' do
-        sass "#sass\n  :background-color white\n  :color black\n",
+      get('/expanded_normal') do
+        sass(
+          "#sass\n  :background-color white\n  :color black\n",
           :style => :expanded, :attribute_syntax => :normal
+        )
       end
-    }
+    end
     get '/'
     assert ok?
     assert_equal "#sass { background-color: white; color: black; }\n", body
